@@ -1,5 +1,5 @@
 use std::cmp::Ordering;
-use std::convert::AsRef;
+use std::convert::{AsRef, TryFrom, TryInto};
 use std::fmt::{Debug, Display, Formatter};
 use std::hash::{Hash, Hasher};
 use std::io::{Error, ErrorKind, Write};
@@ -562,7 +562,7 @@ const SECP256K1_N: U256 =
 const SECP256K1_N_HALF_ONE: U256 =
     U256([0xdfe92f46681b20a1, 0x5d576e7357a4501d, 0xffffffffffffffff, 0x7fffffffffffffff]);
 
-#[derive(Clone, Hash)]
+#[derive(Clone)]
 pub struct Secp256K1Signature([u8; 65]);
 
 impl Secp256K1Signature {
@@ -668,15 +668,6 @@ pub enum Signature {
     SECP256K1(Secp256K1Signature),
 }
 
-impl Hash for Signature {
-    fn hash<H: Hasher>(&self, state: &mut H) {
-        match self {
-            Signature::ED25519(sig) => sig.to_bytes().hash(state),
-            Signature::SECP256K1(sig) => sig.hash(state),
-        };
-    }
-}
-
 impl Signature {
     /// Construct Signature from key type and raw signature blob
     pub fn from_parts(
